Python: package boodle

boodle | index boodle/__init__.py

`# Boodler: a programmable soundscape tool
# Copyright 2001-9 by Andrew Plotkin <erkyrath@eblong.com>
# <http://boodler.org/>
# This program is distributed under the LGPL.
# See the LGPL document, or the above URL, for details.`

Package Contents
`` |  |
agent builtin cboodle_file | cboodle_macosx cboodle_osxaq cboodle_stdout | generator listen music | sample stereo

Data
`` |  | __all__ = ['agent', 'builtin', 'generator', 'listen', 'sample', 'stereo', 'music']